@@ -58,10 +58,30 @@ static guint XfdashboardApplicationsMenuModelSignals[SIGNAL_LAST]={ 0, };
 
 /* IMPLEMENTATION: Private variables and methods */
 
+/* Forward declarations */
+static void _xfdashboard_applications_menu_model_fill_model(XfdashboardApplicationsMenuModel *self);
+
+/* A menu was changed and needs to be reloaded */
+static void _xfdashboard_applications_menu_model_on_reload_required(XfdashboardApplicationsMenuModel *self,
+																	gpointer inUserData)
+{
+	GarconMenu		*menu;
+
+	g_return_if_fail(GARCON_IS_MENU(inUserData));
+
+	menu=GARCON_MENU(inUserData);
+
+	/* Reload menu by filling it again. This also emits all necessary signals. */
+	g_debug("Menu '%s' changed and needs to be reloaded.", garcon_menu_element_get_name(GARCON_MENU_ELEMENT(menu)));
+	_xfdashboard_applications_menu_model_fill_model(self);
+}
+
 /* Clear all data in model and also release all allocated resources needed for this model */
 static void _xfdashboard_applications_menu_model_clear(XfdashboardApplicationsMenuModel *self)
 {
 	XfdashboardApplicationsMenuModelPrivate		*priv;
+	ClutterModelIter							*iterator;
+	GarconMenuElement							*menuElement;
 
 	g_return_if_fail(XFDASHBOARD_IS_APPLICATIONS_MENU_MODEL(self));
 
@@ -70,8 +90,30 @@ static void _xfdashboard_applications_menu_model_clear(XfdashboardApplicationsMe
 	/* Unset filter (forces all rows being accessible and not being skipped/filtered) */
 	clutter_model_set_filter(CLUTTER_MODEL(self), NULL, NULL, NULL);
 
-	/* Remove all rows */
-	while(clutter_model_get_n_rows(CLUTTER_MODEL(self))) clutter_model_remove(CLUTTER_MODEL(self), 0);
+	/* Clean up and remove all rows */
+	while(clutter_model_get_n_rows(CLUTTER_MODEL(self)))
+	{
+		/* Get data from model for clean up */
+		menuElement=NULL;
+
+		iterator=clutter_model_get_iter_at_row(CLUTTER_MODEL(self), 0);
+		clutter_model_iter_get(iterator,
+								XFDASHBOARD_APPLICATIONS_MENU_MODEL_COLUMN_MENU_ELEMENT, &menuElement,
+								-1);
+
+		/* Remove signal handler from menu element */
+		if(menuElement)
+		{
+			g_signal_handlers_disconnect_by_func(menuElement, G_CALLBACK(_xfdashboard_applications_menu_model_on_reload_required), self);
+		}
+
+		/* Remove row */
+		clutter_model_remove(CLUTTER_MODEL(self), 0);
+
+		/* Release iterator */
+		if(menuElement) g_object_unref(menuElement);
+		g_object_unref(iterator);
+	}
 
 	/* Clear sections */
 	if(priv->sections)
@@ -314,6 +356,9 @@ static void _xfdashboard_applications_menu_model_fill_model_collect_menu(Xfdashb
 	}
 	g_list_free(menuElements);
 
+	/* Connect signal 'reload-required' to recognize changes in menus */
+	g_signal_connect_swapped(inMenu, "reload-required", G_CALLBACK(_xfdashboard_applications_menu_model_on_reload_required), self);
+
 	/* Release allocated resources */
 	g_object_unref(inMenu);
 }
