@@ -37,11 +37,17 @@
 #include "application-button.h"
 #include "enums.h"
 #include "drag-action.h"
+#include "stylable.h"
+#include "focusable.h"
+#include "focus-manager.h"
 
 /* Define this class in GObject system */
-G_DEFINE_TYPE(XfdashboardApplicationsView,
-				xfdashboard_applications_view,
-				XFDASHBOARD_TYPE_VIEW)
+static void _xfdashboard_applications_view_focusable_iface_init(XfdashboardFocusableInterface *iface);
+
+G_DEFINE_TYPE_WITH_CODE(XfdashboardApplicationsView,
+						xfdashboard_applications_view,
+						XFDASHBOARD_TYPE_VIEW,
+						G_IMPLEMENT_INTERFACE(XFDASHBOARD_TYPE_FOCUSABLE, _xfdashboard_applications_view_focusable_iface_init))
 
 /* Private structure - access only by public API if needed */
 #define XFDASHBOARD_APPLICATIONS_VIEW_GET_PRIVATE(obj) \
@@ -51,6 +57,7 @@ struct _XfdashboardApplicationsViewPrivate
 {
 	/* Properties related */
 	XfdashboardViewMode					viewMode;
+	gfloat								spacing;
 	gchar								*parentMenuIcon;
 	gchar								*formatTitleOnly;
 	gchar								*formatTitleDescription;
@@ -59,6 +66,9 @@ struct _XfdashboardApplicationsViewPrivate
 	ClutterLayoutManager				*layout;
 	XfdashboardApplicationsMenuModel	*apps;
 	GarconMenuElement					*currentRootMenuElement;
+
+	gboolean							hasFocus;
+	ClutterActor						*selectedItem;
 };
 
 /* Properties */
@@ -67,6 +77,7 @@ enum
 	PROP_0,
 
 	PROP_VIEW_MODE,
+	PROP_SPACING,
 
 	PROP_PARENT_MENU_ICON,
 	PROP_FORMAT_TITLE_ONLY,
@@ -78,10 +89,6 @@ enum
 static GParamSpec* XfdashboardApplicationsViewProperties[PROP_LAST]={ 0, };
 
 /* IMPLEMENTATION: Private variables and methods */
-#define ACTOR_USER_DATA_KEY			"xfdashboard-applications-view-user-data"
-
-#define DEFAULT_SPACING				4.0f						// TODO: Replace by layout
-// TODO: #define DEFAULT_PARENT_MENU_ICON	GTK_STOCK_GO_UP				// TODO: Replace by settings/theming object
 
 /* Forward declarations */
 static void _xfdashboard_applications_view_on_item_clicked(XfdashboardApplicationsView *self, gpointer inUserData);
@@ -223,6 +230,7 @@ static void _xfdashboard_applications_view_on_filter_changed(XfdashboardApplicat
 	priv=XFDASHBOARD_APPLICATIONS_VIEW(self)->priv;
 
 	/* Destroy all children */
+	priv->selectedItem=NULL;
 	clutter_actor_destroy_all_children(CLUTTER_ACTOR(self));
 	clutter_layout_manager_layout_changed(priv->layout);
 
@@ -248,8 +256,8 @@ static void _xfdashboard_applications_view_on_filter_changed(XfdashboardApplicat
 		xfdashboard_button_set_text(XFDASHBOARD_BUTTON(actor), actorText);
 		g_free(actorText);
 
-		if(priv->viewMode==XFDASHBOARD_VIEW_MODE_LIST) xfdashboard_actor_add_style_class(XFDASHBOARD_ACTOR(actor), "view-mode-list");
-			else xfdashboard_actor_add_style_class(XFDASHBOARD_ACTOR(actor), "view-mode-icon");
+		if(priv->viewMode==XFDASHBOARD_VIEW_MODE_LIST) xfdashboard_stylable_add_class(XFDASHBOARD_STYLABLE(actor), "view-mode-list");
+			else xfdashboard_stylable_add_class(XFDASHBOARD_STYLABLE(actor), "view-mode-icon");
 
 		/* Add to view and layout */
 		clutter_actor_set_x_expand(CLUTTER_ACTOR(actor), TRUE);
@@ -258,6 +266,13 @@ static void _xfdashboard_applications_view_on_filter_changed(XfdashboardApplicat
 		clutter_actor_show(actor);
 
 		g_signal_connect_swapped(actor, "clicked", G_CALLBACK(_xfdashboard_applications_view_on_parent_menu_clicked), self);
+
+		/* Select "parent menu" automatically */
+		if(priv->hasFocus)
+		{
+			priv->selectedItem=CLUTTER_ACTOR(actor);
+			xfdashboard_stylable_add_pseudo_class(XFDASHBOARD_STYLABLE(priv->selectedItem), "selected");
+		}
 	}
 
 	/* Iterate through (filtered) data model and create actor for each entry */
@@ -277,8 +292,8 @@ static void _xfdashboard_applications_view_on_filter_changed(XfdashboardApplicat
 			 * menu element is a menu item.
 			 */
 			actor=xfdashboard_application_button_new_from_menu(menuElement);
-			if(priv->viewMode==XFDASHBOARD_VIEW_MODE_LIST) xfdashboard_actor_add_style_class(XFDASHBOARD_ACTOR(actor), "view-mode-list");
-				else xfdashboard_actor_add_style_class(XFDASHBOARD_ACTOR(actor), "view-mode-icon");
+			if(priv->viewMode==XFDASHBOARD_VIEW_MODE_LIST) xfdashboard_stylable_add_class(XFDASHBOARD_STYLABLE(actor), "view-mode-list");
+				else xfdashboard_stylable_add_class(XFDASHBOARD_STYLABLE(actor), "view-mode-icon");
 
 			/* Add to view and layout */
 			clutter_actor_set_x_expand(CLUTTER_ACTOR(actor), TRUE);
@@ -297,6 +312,15 @@ static void _xfdashboard_applications_view_on_filter_changed(XfdashboardApplicat
 				g_signal_connect(dragAction, "drag-end", G_CALLBACK(_xfdashboard_applications_view_on_drag_end), self);
 			}
 
+			/* If no item was selected (i.e. no "parent menu" item) select this one
+			 * which is usually the first menu item.
+			 */
+			if(priv->hasFocus && !priv->selectedItem)
+			{
+				priv->selectedItem=CLUTTER_ACTOR(actor);
+				xfdashboard_stylable_add_pseudo_class(XFDASHBOARD_STYLABLE(priv->selectedItem), "selected");
+			}
+
 			/* Release allocated resources */
 			g_object_unref(menuElement);
 			menuElement=NULL;
@@ -324,6 +348,373 @@ static void _xfdashboard_applications_view_on_model_loaded(XfdashboardApplicatio
 	xfdashboard_applications_menu_model_filter_by_section(priv->apps, GARCON_MENU(priv->currentRootMenuElement));
 }
 
+/* IMPLEMENTATION: Interface XfdashboardFocusable */
+
+/* Determine if actor can get the focus */
+static gboolean _xfdashboard_applications_view_focusable_can_focus(XfdashboardFocusable *inFocusable)
+{
+	XfdashboardApplicationsView			*self;
+	XfdashboardFocusableInterface		*selfIface;
+	XfdashboardFocusableInterface		*parentIface;
+
+	g_return_val_if_fail(XFDASHBOARD_IS_FOCUSABLE(inFocusable), FALSE);
+	g_return_val_if_fail(XFDASHBOARD_IS_APPLICATIONS_VIEW(inFocusable), FALSE);
+
+	self=XFDASHBOARD_APPLICATIONS_VIEW(inFocusable);
+
+	/* Call parent class interface function */
+	selfIface=XFDASHBOARD_FOCUSABLE_GET_IFACE(inFocusable);
+	parentIface=g_type_interface_peek_parent(selfIface);
+
+	if(parentIface && parentIface->can_focus)
+	{
+		if(!parentIface->can_focus(inFocusable)) return(FALSE);
+	}
+
+	/* If this view is not enabled it is not focusable */
+	if(!xfdashboard_view_get_enabled(XFDASHBOARD_VIEW(self))) return(FALSE);
+
+	/* If we get here this actor can be focused */
+	return(TRUE);
+}
+
+/* Set focus to actor */
+static void _xfdashboard_applications_view_focusable_set_focus(XfdashboardFocusable *inFocusable)
+{
+	XfdashboardApplicationsView				*self;
+	XfdashboardApplicationsViewPrivate		*priv;
+	XfdashboardFocusableInterface			*selfIface;
+	XfdashboardFocusableInterface			*parentIface;
+
+	g_return_if_fail(XFDASHBOARD_IS_FOCUSABLE(inFocusable));
+	g_return_if_fail(XFDASHBOARD_IS_APPLICATIONS_VIEW(inFocusable));
+
+	self=XFDASHBOARD_APPLICATIONS_VIEW(inFocusable);
+	priv=self->priv;
+
+	/* Call parent class interface function */
+	selfIface=XFDASHBOARD_FOCUSABLE_GET_IFACE(inFocusable);
+	parentIface=g_type_interface_peek_parent(selfIface);
+
+	if(parentIface && parentIface->set_focus)
+	{
+		parentIface->set_focus(inFocusable);
+	}
+
+	/* Reset selected item to first one */
+	if(!priv->selectedItem)
+	{
+		priv->selectedItem=clutter_actor_get_first_child(CLUTTER_ACTOR(self));
+	}
+
+	if(priv->selectedItem)
+	{
+		xfdashboard_stylable_add_pseudo_class(XFDASHBOARD_STYLABLE(priv->selectedItem), "selected");
+	}
+
+	/* This view gained focus */
+	priv->hasFocus=TRUE;
+}
+
+/* Unset focus from actor */
+static void _xfdashboard_applications_view_focusable_unset_focus(XfdashboardFocusable *inFocusable)
+{
+	XfdashboardApplicationsView				*self;
+	XfdashboardApplicationsViewPrivate		*priv;
+	XfdashboardFocusableInterface			*selfIface;
+	XfdashboardFocusableInterface			*parentIface;
+
+	g_return_if_fail(XFDASHBOARD_IS_FOCUSABLE(inFocusable));
+	g_return_if_fail(XFDASHBOARD_IS_APPLICATIONS_VIEW(inFocusable));
+
+	self=XFDASHBOARD_APPLICATIONS_VIEW(inFocusable);
+	priv=self->priv;
+
+	/* Call parent class interface function */
+	selfIface=XFDASHBOARD_FOCUSABLE_GET_IFACE(inFocusable);
+	parentIface=g_type_interface_peek_parent(selfIface);
+
+	if(parentIface && parentIface->set_focus)
+	{
+		parentIface->unset_focus(inFocusable);
+	}
+
+	/* Unstyle selected item */
+	if(priv->selectedItem)
+	{
+		xfdashboard_stylable_remove_pseudo_class(XFDASHBOARD_STYLABLE(priv->selectedItem), "selected");
+	}
+
+	/* This view lost focus */
+	priv->hasFocus=FALSE;
+}
+
+/* Virtual function "handle_key_event" was called */
+static gboolean _xfdashboard_applications_view_focusable_handle_key_event_at_icon_mode(XfdashboardApplicationsView *self,
+																						const ClutterEvent *inEvent)
+{
+	XfdashboardApplicationsViewPrivate	*priv;
+	gint								numberChildren, rows, columns;
+	gint								selectionIndex, newSelectionIndex;
+	gfloat								lastX, lastY;
+	ClutterActorIter					iter;
+	ClutterActor						*child;
+	ClutterActorBox						childBox;
+	ClutterActor						*newSelection;
+	gint								i;
+	gboolean							gotColumns;
+
+	g_return_val_if_fail(XFDASHBOARD_IS_APPLICATIONS_VIEW(self), CLUTTER_EVENT_PROPAGATE);
+
+	priv=self->priv;
+
+	/* Determine number of rows and columns and total number of children */
+	numberChildren=rows=columns=0;
+	selectionIndex=-1;
+	lastX=lastY=0.0f;
+	gotColumns=FALSE;
+	clutter_actor_iter_init(&iter, CLUTTER_ACTOR(self));
+	while(clutter_actor_iter_next(&iter, &child))
+	{
+		/* Only count visible children */
+		if(!CLUTTER_ACTOR_IS_VISIBLE(child)) continue;
+
+		/* If x coordinate of this child is smaller than the one of last child
+		 * or if y coordinate is larger then a new row begins and we know
+		 * the number of columns.
+		 */
+		clutter_actor_get_allocation_box(child, &childBox);
+		if(!gotColumns &&
+			(childBox.x1<lastX || childBox.y1>lastY))
+		{
+			columns=numberChildren;
+			gotColumns=TRUE;
+		}
+		lastX=childBox.x1;
+		lastY=childBox.y1;
+
+		/* If current child is the selected one remember its index */
+		if(child==priv->selectedItem) selectionIndex=numberChildren;
+
+		/* Count total number of children */
+		numberChildren++;
+	}
+
+	if(gotColumns)
+	{
+		rows=1+(numberChildren/columns);
+	}
+		else if(numberChildren>0)
+		{
+			rows=1;
+			columns=numberChildren;
+		}
+
+	/* Determine index of new item to select */
+	if(selectionIndex<0)
+	{
+		g_warning(_("Current selected item not found. Selecting first item."));
+		selectionIndex=0;
+	}
+
+	switch(inEvent->key.keyval)
+	{
+		case CLUTTER_KEY_Up:
+			newSelectionIndex=selectionIndex-columns;
+			if(newSelectionIndex<0)
+			{
+				newSelectionIndex+=(rows*columns);
+				while(newSelectionIndex>=numberChildren && newSelectionIndex>selectionIndex)
+				{
+					newSelectionIndex-=columns;
+				}
+			}
+			break;
+
+		case CLUTTER_KEY_Down:
+			newSelectionIndex=selectionIndex+columns;
+			if(newSelectionIndex>=numberChildren)
+			{
+				newSelectionIndex=(selectionIndex % columns);
+				if(newSelectionIndex>=numberChildren) newSelectionIndex=selectionIndex;
+			}
+			break;
+
+		case CLUTTER_KEY_Left:
+			newSelectionIndex=selectionIndex-1;
+			if(newSelectionIndex<0 ||
+				(newSelectionIndex/columns)!=(selectionIndex/columns))
+			{
+				newSelectionIndex=((selectionIndex/columns)*columns)+columns-1;
+			}
+			break;
+
+		case CLUTTER_KEY_Right:
+			newSelectionIndex=selectionIndex+1;
+			if(newSelectionIndex>=numberChildren ||
+				(newSelectionIndex/columns)!=(selectionIndex/columns))
+			{
+				newSelectionIndex=(selectionIndex/columns)*columns;
+			}
+			break;
+
+		default:
+			newSelectionIndex=selectionIndex;
+			break;
+	}
+
+	/* If selection did not changed do nothing */
+	if(newSelectionIndex==selectionIndex) return(CLUTTER_EVENT_STOP);
+
+	/* Find new item to select */
+	i=0;
+	newSelection=NULL;
+	clutter_actor_iter_init(&iter, CLUTTER_ACTOR(self));
+	while(clutter_actor_iter_next(&iter, &child) &&
+			!newSelection)
+	{
+		/* Only count visible children */
+		if(!CLUTTER_ACTOR_IS_VISIBLE(child)) continue;
+
+		/* Check for child to lookup */
+		if(i==newSelectionIndex)
+		{
+			newSelection=child;
+			break;
+		}
+
+		/* Continue with next child */
+		i++;
+	}
+
+	/* If selection did not changed do nothing */
+	if(!newSelection || newSelection==priv->selectedItem) return(CLUTTER_EVENT_STOP);
+
+	/* Unstyle current selection */
+	xfdashboard_stylable_remove_pseudo_class(XFDASHBOARD_STYLABLE(priv->selectedItem), "selected");
+
+	/* Remember and style new selection */
+	priv->selectedItem=newSelection;
+	xfdashboard_stylable_add_pseudo_class(XFDASHBOARD_STYLABLE(priv->selectedItem), "selected");
+
+	/* Ensure new selection is visible */
+	xfdashboard_view_ensure_visible(XFDASHBOARD_VIEW(self), newSelection);
+
+	/* Event handled */
+	return(CLUTTER_EVENT_STOP);
+}
+
+static gboolean _xfdashboard_applications_view_focusable_handle_key_event_at_list_mode(XfdashboardApplicationsView *self,
+																						const ClutterEvent *inEvent)
+{
+	XfdashboardApplicationsViewPrivate		*priv;
+	ClutterActor							*newSelection;
+
+	g_return_val_if_fail(XFDASHBOARD_IS_APPLICATIONS_VIEW(self), CLUTTER_EVENT_PROPAGATE);
+
+	priv=self->priv;
+	newSelection=NULL;
+
+	/* Get new selected item */
+	if(inEvent->key.keyval==CLUTTER_KEY_Up)
+	{
+		/* Get previous item to select */
+		if(priv->selectedItem) newSelection=clutter_actor_get_previous_sibling(priv->selectedItem);
+
+		/* If there is no previous item, e.g. at begin of list, select last item in list */
+		if(!newSelection) newSelection=clutter_actor_get_last_child(CLUTTER_ACTOR(self));
+	}
+
+	if(inEvent->key.keyval==CLUTTER_KEY_Down)
+	{
+		/* Get next item to select */
+		if(priv->selectedItem) newSelection=clutter_actor_get_next_sibling(priv->selectedItem);
+
+		/* If there is no next item, e.g. at end of list, select first item in list */
+		if(!newSelection) newSelection=clutter_actor_get_first_child(CLUTTER_ACTOR(self));
+	}
+
+	/* If selection did not changed do nothing */
+	if(!newSelection || newSelection==priv->selectedItem) return(CLUTTER_EVENT_STOP);
+
+	/* Unstyle current selection */
+	xfdashboard_stylable_remove_pseudo_class(XFDASHBOARD_STYLABLE(priv->selectedItem), "selected");
+
+	/* Remember and style new selection */
+	priv->selectedItem=newSelection;
+	xfdashboard_stylable_add_pseudo_class(XFDASHBOARD_STYLABLE(priv->selectedItem), "selected");
+
+	/* Ensure new selection is visible */
+	xfdashboard_view_ensure_visible(XFDASHBOARD_VIEW(self), newSelection);
+
+	/* Event handled */
+	return(CLUTTER_EVENT_STOP);
+}
+
+static gboolean _xfdashboard_applications_view_focusable_handle_key_event(XfdashboardFocusable *inFocusable,
+																			const ClutterEvent *inEvent)
+{
+	XfdashboardApplicationsView				*self;
+	XfdashboardApplicationsViewPrivate		*priv;
+	gboolean								handledEvent;
+
+	g_return_val_if_fail(XFDASHBOARD_IS_FOCUSABLE(inFocusable), CLUTTER_EVENT_PROPAGATE);
+	g_return_val_if_fail(XFDASHBOARD_IS_APPLICATIONS_VIEW(inFocusable), CLUTTER_EVENT_PROPAGATE);
+
+	self=XFDASHBOARD_APPLICATIONS_VIEW(inFocusable);
+	priv=self->priv;
+
+	/* Handle key events when key was released */
+	if(clutter_event_type(inEvent)==CLUTTER_KEY_RELEASE)
+	{
+		/* Start selected application on ENTER */
+		switch(inEvent->key.keyval)
+		{
+			case CLUTTER_KEY_Return:
+			case CLUTTER_KEY_KP_Enter:
+			case CLUTTER_KEY_ISO_Enter:
+				if(priv->selectedItem)
+				{
+					if(XFDASHBOARD_IS_APPLICATION_BUTTON(priv->selectedItem))
+					{
+						_xfdashboard_applications_view_on_item_clicked(self, XFDASHBOARD_APPLICATION_BUTTON(priv->selectedItem));
+					}
+						else if(XFDASHBOARD_IS_BUTTON(priv->selectedItem))
+						{
+							_xfdashboard_applications_view_on_parent_menu_clicked(self, XFDASHBOARD_BUTTON(priv->selectedItem));
+						}
+				}
+				return(CLUTTER_EVENT_STOP);
+		}
+
+		/* Move selection if an arrow key was pressed */
+		if(priv->viewMode==XFDASHBOARD_VIEW_MODE_LIST)
+		{
+			handledEvent=_xfdashboard_applications_view_focusable_handle_key_event_at_list_mode(self, inEvent);
+		}
+			else
+			{
+				handledEvent=_xfdashboard_applications_view_focusable_handle_key_event_at_icon_mode(self, inEvent);
+			}
+
+		if(handledEvent==CLUTTER_EVENT_STOP) return(handledEvent);
+	}
+
+	/* We did not handle this event */
+	return(CLUTTER_EVENT_PROPAGATE);
+}
+
+/* Interface initialization
+ * Set up default functions
+ */
+void _xfdashboard_applications_view_focusable_iface_init(XfdashboardFocusableInterface *iface)
+{
+	iface->can_focus=_xfdashboard_applications_view_focusable_can_focus;
+	iface->set_focus=_xfdashboard_applications_view_focusable_set_focus;
+	iface->unset_focus=_xfdashboard_applications_view_focusable_unset_focus;
+	iface->handle_key_event=_xfdashboard_applications_view_focusable_handle_key_event;
+}
+
 /* IMPLEMENTATION: GObject */
 
 /* Dispose this object */
@@ -379,6 +770,10 @@ static void _xfdashboard_applications_view_set_property(GObject *inObject,
 			xfdashboard_applications_view_set_view_mode(self, (XfdashboardViewMode)g_value_get_enum(inValue));
 			break;
 
+		case PROP_SPACING:
+			xfdashboard_applications_view_set_spacing(self, g_value_get_float(inValue));
+			break;
+
 		case PROP_PARENT_MENU_ICON:
 			xfdashboard_applications_view_set_parent_menu_icon(self, g_value_get_string(inValue));
 			break;
@@ -414,6 +809,10 @@ static void _xfdashboard_applications_view_get_property(GObject *inObject,
 			g_value_set_enum(outValue, priv->viewMode);
 			break;
 
+		case PROP_SPACING:
+			g_value_set_float(outValue, priv->spacing);
+			break;
+
 		case PROP_PARENT_MENU_ICON:
 			g_value_set_string(outValue, priv->parentMenuIcon);
 			break;
@@ -456,33 +855,42 @@ static void xfdashboard_applications_view_class_init(XfdashboardApplicationsView
 							_("The view mode used in this view"),
 							XFDASHBOARD_TYPE_VIEW_MODE,
 							XFDASHBOARD_VIEW_MODE_LIST,
-							G_PARAM_READWRITE);
+							G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
+
+	XfdashboardApplicationsViewProperties[PROP_SPACING]=
+		g_param_spec_float("spacing",
+							_("Spacing"),
+							_("Spacing between each element in view"),
+							0.0f, G_MAXFLOAT,
+							0.0f,
+							G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
 
 	XfdashboardApplicationsViewProperties[PROP_PARENT_MENU_ICON]=
 		g_param_spec_string("parent-menu-icon",
 								_("Parent menu icon"),
 								_("Name of icon to use for 'go-back-to-parent-menu' entries"),
 								NULL,
-								G_PARAM_READWRITE);
+								G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
 
 	XfdashboardApplicationsViewProperties[PROP_FORMAT_TITLE_ONLY]=
 		g_param_spec_string("format-title-only",
 								_("Format title only"),
 								_("Format string used when only title is display"),
 								NULL,
-								G_PARAM_READWRITE);
+								G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
 
 	XfdashboardApplicationsViewProperties[PROP_FORMAT_TITLE_DESCRIPTION]=
 		g_param_spec_string("format-title-description",
 								_("Format title and description"),
 								_("Format string used when title and description is display. First argument is title and second one is description."),
 								NULL,
-								G_PARAM_READWRITE);
+								G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
 
 	g_object_class_install_properties(gobjectClass, PROP_LAST, XfdashboardApplicationsViewProperties);
 
 	/* Define stylable properties */
 	xfdashboard_actor_install_stylable_property(actorClass, XfdashboardApplicationsViewProperties[PROP_VIEW_MODE]);
+	xfdashboard_actor_install_stylable_property(actorClass, XfdashboardApplicationsViewProperties[PROP_SPACING]);
 	xfdashboard_actor_install_stylable_property(actorClass, XfdashboardApplicationsViewProperties[PROP_PARENT_MENU_ICON]);
 	xfdashboard_actor_install_stylable_property(actorClass, XfdashboardApplicationsViewProperties[PROP_FORMAT_TITLE_ONLY]);
 	xfdashboard_actor_install_stylable_property(actorClass, XfdashboardApplicationsViewProperties[PROP_FORMAT_TITLE_DESCRIPTION]);
@@ -501,9 +909,12 @@ static void xfdashboard_applications_view_init(XfdashboardApplicationsView *self
 	priv->apps=XFDASHBOARD_APPLICATIONS_MENU_MODEL(xfdashboard_applications_menu_model_new());
 	priv->currentRootMenuElement=NULL;
 	priv->viewMode=-1;
+	priv->spacing=0.0f;
 	priv->parentMenuIcon=NULL;
 	priv->formatTitleOnly=g_strdup("%s");
 	priv->formatTitleDescription=g_strdup("%s\n%s");
+	priv->hasFocus=FALSE;
+	priv->selectedItem=NULL;
 
 	/* Set up view */
 	xfdashboard_view_set_internal_name(XFDASHBOARD_VIEW(self), "applications");
@@ -511,6 +922,8 @@ static void xfdashboard_applications_view_init(XfdashboardApplicationsView *self
 	xfdashboard_view_set_icon(XFDASHBOARD_VIEW(self), GTK_STOCK_HOME);
 
 	/* Set up actor */
+	xfdashboard_actor_set_can_focus(XFDASHBOARD_ACTOR(self), TRUE);
+
 	xfdashboard_view_set_fit_mode(XFDASHBOARD_VIEW(self), XFDASHBOARD_FIT_MODE_HORIZONTAL);
 	xfdashboard_applications_view_set_view_mode(self, XFDASHBOARD_VIEW_MODE_LIST);
 	clutter_model_set_sorting_column(CLUTTER_MODEL(priv->apps), XFDASHBOARD_APPLICATIONS_MENU_MODEL_COLUMN_TITLE);
@@ -555,14 +968,14 @@ void xfdashboard_applications_view_set_view_mode(XfdashboardApplicationsView *se
 			case XFDASHBOARD_VIEW_MODE_LIST:
 				priv->layout=clutter_box_layout_new();
 				clutter_box_layout_set_orientation(CLUTTER_BOX_LAYOUT(priv->layout), CLUTTER_ORIENTATION_VERTICAL);
-				clutter_box_layout_set_spacing(CLUTTER_BOX_LAYOUT(priv->layout), DEFAULT_SPACING);
+				clutter_box_layout_set_spacing(CLUTTER_BOX_LAYOUT(priv->layout), priv->spacing);
 				clutter_actor_set_layout_manager(CLUTTER_ACTOR(self), priv->layout);
 				break;
 
 			case XFDASHBOARD_VIEW_MODE_ICON:
 				priv->layout=clutter_flow_layout_new(CLUTTER_FLOW_HORIZONTAL);
-				clutter_flow_layout_set_column_spacing(CLUTTER_FLOW_LAYOUT(priv->layout), DEFAULT_SPACING);
-				clutter_flow_layout_set_row_spacing(CLUTTER_FLOW_LAYOUT(priv->layout), DEFAULT_SPACING);
+				clutter_flow_layout_set_column_spacing(CLUTTER_FLOW_LAYOUT(priv->layout), priv->spacing);
+				clutter_flow_layout_set_row_spacing(CLUTTER_FLOW_LAYOUT(priv->layout), priv->spacing);
 				clutter_flow_layout_set_homogeneous(CLUTTER_FLOW_LAYOUT(priv->layout), TRUE);
 				clutter_actor_set_layout_manager(CLUTTER_ACTOR(self), priv->layout);
 				break;
@@ -579,6 +992,52 @@ void xfdashboard_applications_view_set_view_mode(XfdashboardApplicationsView *se
 	}
 }
 
+/* Get/set spacing between elements */
+gfloat xfdashboard_applications_view_get_spacing(XfdashboardApplicationsView *self)
+{
+	g_return_val_if_fail(XFDASHBOARD_IS_APPLICATIONS_VIEW(self), 0.0f);
+
+	return(self->priv->spacing);
+}
+
+void xfdashboard_applications_view_set_spacing(XfdashboardApplicationsView *self, const gfloat inSpacing)
+{
+	XfdashboardApplicationsViewPrivate		*priv;
+
+	g_return_if_fail(XFDASHBOARD_IS_APPLICATIONS_VIEW(self));
+	g_return_if_fail(inSpacing>=0.0f);
+
+	priv=self->priv;
+
+	/* Set value if changed */
+	if(priv->spacing!=inSpacing)
+	{
+		/* Set value */
+		priv->spacing=inSpacing;
+
+		/* Update layout manager */
+		switch(priv->viewMode)
+		{
+			case XFDASHBOARD_VIEW_MODE_LIST:
+				clutter_box_layout_set_spacing(CLUTTER_BOX_LAYOUT(priv->layout), priv->spacing);
+				break;
+
+			case XFDASHBOARD_VIEW_MODE_ICON:
+				clutter_flow_layout_set_column_spacing(CLUTTER_FLOW_LAYOUT(priv->layout), priv->spacing);
+				clutter_flow_layout_set_row_spacing(CLUTTER_FLOW_LAYOUT(priv->layout), priv->spacing);
+				break;
+
+			default:
+				g_assert_not_reached();
+		}
+
+		/* Notify about property change */
+		g_object_notify_by_pspec(G_OBJECT(self), XfdashboardApplicationsViewProperties[PROP_SPACING]);
+	}
+}
+
+/* Implementation: Public API */
+
 /* Get/set icon name for 'go-back-to-parent-menu' entries */
 const gchar* xfdashboard_applications_view_get_parent_menu_icon(XfdashboardApplicationsView *self)
 {
@@ -639,8 +1098,8 @@ void xfdashboard_applications_view_set_format_title_only(XfdashboardApplications
 		if(priv->formatTitleOnly) g_free(priv->formatTitleOnly);
 		priv->formatTitleOnly=g_strdup(inFormat);
 
-		/* Update actor */
-		_xfdashboard_applications_view_on_filter_changed(self, NULL);
+		/* Update view only if view mode is list which uses this format string */
+		if(priv->viewMode==XFDASHBOARD_VIEW_MODE_ICON) _xfdashboard_applications_view_on_filter_changed(self, NULL);
 
 		/* Notify about property change */
 		g_object_notify_by_pspec(G_OBJECT(self), XfdashboardApplicationsViewProperties[PROP_FORMAT_TITLE_ONLY]);
@@ -668,11 +1127,11 @@ void xfdashboard_applications_view_set_format_title_description(XfdashboardAppli
 	if(g_strcmp0(priv->formatTitleDescription, inFormat)!=0)
 	{
 		/* Set value */
-		if(priv->formatTitleOnly) g_free(priv->formatTitleDescription);
+		if(priv->formatTitleDescription) g_free(priv->formatTitleDescription);
 		priv->formatTitleDescription=g_strdup(inFormat);
 
-		/* Update actor */
-		_xfdashboard_applications_view_on_filter_changed(self, NULL);
+		/* Update view only if view mode is list which uses this format string */
+		if(priv->viewMode==XFDASHBOARD_VIEW_MODE_LIST) _xfdashboard_applications_view_on_filter_changed(self, NULL);
 
 		/* Notify about property change */
 		g_object_notify_by_pspec(G_OBJECT(self), XfdashboardApplicationsViewProperties[PROP_FORMAT_TITLE_DESCRIPTION]);
