@@ -31,6 +31,33 @@
 #include "enums.h"
 
 
+/* enumerations from "theme.h" */
+#include "theme.h"
+
+GType xfdashboard_theme_error_enum_get_type(void)
+{
+	static volatile gsize	g_define_type_id__volatile=0;
+
+	if(g_once_init_enter(&g_define_type_id__volatile))
+	{
+		static const GEnumValue values[]=
+		{
+			{ XFDASHBOARD_THEME_ERROR_GENERAL_ERROR, "XFDASHBOARD_THEME_ERROR_GENERAL_ERROR", "general-error" },
+			{ XFDASHBOARD_THEME_ERROR_ALREADY_LOADED, "XFDASHBOARD_THEME_ERROR_ALREADY_LOADED", "already-loaded" },
+			{ XFDASHBOARD_THEME_ERROR_THEME_NOT_FOUND, "XFDASHBOARD_THEME_ERROR_THEME_NOT_FOUND", "theme-not-found" },
+			{ XFDASHBOARD_THEME_ERROR_INVALID_THEME_FILE, "XFDASHBOARD_THEME_ERROR_INVALID_THEME_FILE", "invalid-theme-file" },
+			{ XFDASHBOARD_THEME_ERROR_RESOURCE_NOT_FOUND, "XFDASHBOARD_THEME_ERROR_RESOURCE_NOT_FOUND", "resource-not-found" },
+			{ 0, NULL, NULL }
+		};
+
+		GType	g_define_type_id=g_enum_register_static(g_intern_static_string("XfdashboardThemeErrorEnum"), values);
+		g_once_init_leave(&g_define_type_id__volatile, g_define_type_id);
+	}
+
+	return(g_define_type_id__volatile);
+}
+
+
 /* enumerations from "theme-css.h" */
 #include "theme-css.h"
 
@@ -56,6 +83,30 @@ GType xfdashboard_theme_css_error_enum_get_type(void)
 }
 
 
+/* enumerations from "theme-layout.h" */
+#include "theme-layout.h"
+
+GType xfdashboard_theme_layout_error_enum_get_type(void)
+{
+	static volatile gsize	g_define_type_id__volatile=0;
+
+	if(g_once_init_enter(&g_define_type_id__volatile))
+	{
+		static const GEnumValue values[]=
+		{
+			{ XFDASHBOARD_THEME_LAYOUT_ERROR_ERROR, "XFDASHBOARD_THEME_LAYOUT_ERROR_ERROR", "error" },
+			{ XFDASHBOARD_THEME_LAYOUT_ERROR_MALFORMED, "XFDASHBOARD_THEME_LAYOUT_ERROR_MALFORMED", "malformed" },
+			{ 0, NULL, NULL }
+		};
+
+		GType	g_define_type_id=g_enum_register_static(g_intern_static_string("XfdashboardThemeLayoutErrorEnum"), values);
+		g_once_init_leave(&g_define_type_id__volatile, g_define_type_id);
+	}
+
+	return(g_define_type_id__volatile);
+}
+
+
 /* enumerations from "types.h" */
 #include "types.h"
 
@@ -193,6 +244,30 @@ GType xfdashboard_corners_get_type(void)
 	return(g_define_type_id__volatile);
 }
 
+GType xfdashboard_borders_get_type(void)
+{
+	static volatile gsize	g_define_type_id__volatile=0;
+
+	if(g_once_init_enter(&g_define_type_id__volatile))
+	{
+		static const GFlagsValue values[]=
+		{
+			{ XFDASHBOARD_BORDERS_NONE, "XFDASHBOARD_BORDERS_NONE", "none" },
+			{ XFDASHBOARD_BORDERS_LEFT, "XFDASHBOARD_BORDERS_LEFT", "left" },
+			{ XFDASHBOARD_BORDERS_TOP, "XFDASHBOARD_BORDERS_TOP", "top" },
+			{ XFDASHBOARD_BORDERS_RIGHT, "XFDASHBOARD_BORDERS_RIGHT", "right" },
+			{ XFDASHBOARD_BORDERS_BOTTOM, "XFDASHBOARD_BORDERS_BOTTOM", "bottom" },
+			{ XFDASHBOARD_BORDERS_ALL, "XFDASHBOARD_BORDERS_ALL", "all" },
+			{ 0, NULL, NULL }
+		};
+
+		GType	g_define_type_id=g_flags_register_static(g_intern_static_string("XfdashboardBorders"), values);
+		g_once_init_leave(&g_define_type_id__volatile, g_define_type_id);
+	}
+
+	return(g_define_type_id__volatile);
+}
+
 GType xfdashboard_fit_mode_get_type(void)
 {
 	static volatile gsize	g_define_type_id__volatile=0;
