@@ -48,6 +48,11 @@ void xfdashboard_notify(ClutterActor *inSender, const gchar *inIconName, const g
 
 GAppLaunchContext* xfdashboard_create_app_context(XfdashboardWindowTrackerWorkspace *inWorkspace);
 
+void xfdashboard_register_gvalue_transformation_funcs(void);
+
+gboolean xfdashboard_actor_contains_child_deep(ClutterActor *inActor, ClutterActor *inChild);
+ClutterActor* xfdashboard_find_actor_by_name(ClutterActor *inActor, const gchar *inName);
+
 G_END_DECLS
 
 #endif	/* __XFDASHBOARD_UTILS__ */
