@@ -40,7 +40,6 @@
 
 #include "window-tracker.h"
 #include "marshal.h"
-#include "utils.h"
 
 /* Usually we would define a class in GObject system here but
  * this class is a wrapper around WnckWindow to create a virtual stable
@@ -126,9 +125,21 @@ GType xfdashboard_window_tracker_window_get_type(void)
 /* Determine if window is visible */
 gboolean xfdashboard_window_tracker_window_is_visible(XfdashboardWindowTrackerWindow *inWindow)
 {
+	WnckWindowState		state;
+
 	g_return_val_if_fail(WNCK_IS_WINDOW(inWindow), FALSE);
 
-	return((wnck_window_get_state(WNCK_WINDOW(inWindow)) & WNCK_WINDOW_STATE_HIDDEN) ? FALSE : TRUE);
+	state=wnck_window_get_state(WNCK_WINDOW(inWindow));
+
+	/* Windows are invisible if hidden but not minimized */
+	if((state & WNCK_WINDOW_STATE_HIDDEN) &&
+		!(state & WNCK_WINDOW_STATE_MINIMIZED))
+	{
+		return(FALSE);
+	}
+
+	/* If we get here the window is visible */
+	return(TRUE);
 }
 
 gboolean xfdashboard_window_tracker_window_is_visible_on_workspace(XfdashboardWindowTrackerWindow *inWindow,
@@ -137,7 +148,9 @@ gboolean xfdashboard_window_tracker_window_is_visible_on_workspace(XfdashboardWi
 	g_return_val_if_fail(WNCK_IS_WINDOW(inWindow), FALSE);
 	g_return_val_if_fail(WNCK_IS_WORKSPACE(inWorkspace), FALSE);
 
-	return(wnck_window_is_visible_on_workspace(WNCK_WINDOW(inWindow), WNCK_WORKSPACE(inWorkspace)));
+	/* Check if window is visible generally and if it is on requested workspace */
+	return(xfdashboard_window_tracker_window_is_visible(inWindow) &&
+			wnck_window_is_on_workspace(WNCK_WINDOW(inWindow), WNCK_WORKSPACE(inWorkspace)));
 }
 
 /* Set visibility of window (show/hide) */
